@@ -608,15 +608,14 @@ def files_create( fp , trimpath = "" ) :
     fp_processed = fp
 
     if( trimpath != "" ) :
-        fp_processed = fp[len(trimpath ):]
-
+        fp_processed = fp[ len( trimpath ): ]
 
     statinfo = os.stat( fp )
 
     ####################################################################
 
     sql = "INSERT INTO files ( fp , fc , fs , fh , fm ) VALUES (?, ?, ?, ?,?)"
-    data_tuple = ( fp_processed , fc , fs , fh , statinfo.st_mtime)
+    data_tuple = ( fp_processed , fc , fs , fh , statinfo.st_mtime )
 
     sql_execute( sql , data_tuple )
 
@@ -652,6 +651,28 @@ def files_delete( fp ) :
 def files_deleteall( ) :
     table_truncate( "files" )
 
+
+
+def files_addvirtual( fp , fc ) :
+
+    fs = len( fc )
+
+
+    if type( fc ) is str:
+        fh = hashlib.md5( fc.encode( "utf-8" ) ).hexdigest( )
+    else:
+        fh = hashlib.md5( fc ).hexdigest( )
+
+
+    fm = s_util.time_now( )
+
+    sql = "INSERT INTO files ( fp , fc , fs , fh ,fm) VALUES (?, ?, ?, ?,?)"
+    data_tuple = ( fp , fc , fs , fh ,fm)
+    sql_execute( sql , data_tuple )
+
+    return( True )
+
+
 def files_dict2json( fp , fdict ) :
 
     #if( s_util.pathnotallowed( fp ) ) : return( False )
@@ -698,6 +719,9 @@ def files_write( fp_source , fp_target = False ) :
     fp_target_tmp = fp_target + s_util.uhash( )
 
     with open( fp_target_tmp , "wb" ) as f :
+        if type(fd[ "fc" ]) is str:
+            fd[ "fc" ]=fd[ "fc" ].encode()
+
         f.write( fd[ "fc" ] )
         f.flush( )
 
@@ -724,11 +748,15 @@ def files_append( fp_source , fp_target = False ) :
     if s_util.file_exists( fp_target ) :
         s_log.write( "fp_target exists! " + fp_target )
         with open( fp_target , "ab" ) as f :
+            if type(fd[ "fc" ]) is str:
+                fd[ "fc" ]=fd[ "fc" ].encode()
             f.write( fd[ "fc" ] )
 
     else :
 
         with open( fp_target_tmp , "wb" ) as f :
+            if type(fd[ "fc" ]) is str:
+                fd[ "fc" ]=fd[ "fc" ].encode()
             f.write( fd[ "fc" ] )
 
         s_util.file_replace( fp_target_tmp , fp_target )
@@ -775,14 +803,15 @@ def files_restore( rpath = False , mode = "overwrite" ) :
 
 #        s_util.file_settimes(fp_target,db_file["fm"])
 
-def files_createall( pat ) :
+def files_createall( pat , trim_path = True ) :
     # Let's be clever and try to trim the pattern matching directory...
 
     # FIXME TODO be careful... we are only checking for wildcard "**"
     # FIXME TODO WARNING this removes "chars"!
     pat_trim = pat.rstrip( "**" )
     if( pat_trim == pat ) :
-        pat_trim = ""
+        if(trim_path):
+            pat_trim = ""
 
     files = s_util.glob_files( pat , True )
     for f in files :
