@@ -45,7 +45,7 @@ def isready( ) :
 def config_load_from_file( cp ) :
     return( s_config.load_from_file( cp ) )
 
-def prexit( msg ) :
+def prexit( msg="" ) :
     s_util.printexit( msg )
 
 def exitiferror( ) :
@@ -69,15 +69,21 @@ def reset( ) :
 
 def uptime( ) :
     return( s_util.uptime( ) )
+
 def uptime_lap( ) :
     return( s_util.uptime_lap( ) )
-def log_lap( ) :
-    s_log.write( s_util.uptime_lap( ) )
+
+def log_lap( msg="",consoleprint=False) :
+    t=s_util.uptime_lap()
+    s_log.write( msg+" "+str(t) )
+    if(consoleprint):
+        print(msg+" "+str(t))
 
 def heartbeat( t = 60 ) :
     return( s_util.heartbeat( t ) )
 
 #####################################################################################################
+
 runner_omnibus_ctime = 0
 # Required to make module name scope available in function for importlib
 _sapi_runner_omnibus = None
@@ -97,7 +103,6 @@ def sapirunner_omnibus_reloadifchanged( path_runner ) :
 
     return( True )
 
-
 def runner_omnibus( path_runner ) :
 
     # Required to make module name scope available in function for importlib
@@ -135,7 +140,9 @@ def runner_omnibus( path_runner ) :
         heartbeat( )
 
         #####################################################
+
         if( not sapirunner_omnibus_reloadifchanged( path_runner ) ) : continue
+
         #####################################################
 
         try :
@@ -223,11 +230,11 @@ def runner_omnibus( path_runner ) :
 
         #s_log.write( "OK" )
 
-def omnibus_ping( ) :
-    run( {
-        "_tests_omnibus_ping" : "y"
-    } )
-    return( s_db.meta_read( "_job_state" ) == "done" ) 
+#def omnibus_ping( ) :
+#    run( {
+#        "_tests_omnibus_ping" : "y"
+#    } )
+#    return( s_db.meta_read( "_job_state" ) == "done" ) 
 
 #####################################################################
 
@@ -239,11 +246,9 @@ def run( params = { } , wait_timeout = 60 ) :
     #    s_log.write( "NOT READY" )
     #    return( False )
 
+    tid = s_util.thread_get_id( )
 
-    tid = s_util.thread_get_id()
-
-
-
+    #####################################################################
 
     if( not isinstance( params , ( dict ) ) ) :
         s_log.write( "false params dict" )
